@@ -7,7 +7,7 @@
 */
 
 #include "general.h"  /* must always come first */
-#include "tcl.h"
+#include "x-tcl.h"
 #include "entry.h"
 #include "param.h"
 #include "parse.h"
@@ -42,7 +42,7 @@ static kindDefinition ITclKinds[] = {
 	  ATTACH_SEPARATORS(ITclGenericSeparators)},
 	{ true, 'C', "common", "common variables",
 	  ATTACH_SEPARATORS(ITclGenericSeparators)},
-	{ true, 'p', "procedure", "procedures within the  class  namespace",
+	{ true, 'p', "procedure", "procedures within the class namespace",
 	  ATTACH_SEPARATORS(ITclGenericSeparators)},
 };
 
